@@ -66,8 +66,7 @@ RPMFILES="acconfig.h               \
           src/*/*.in               \
           src/*/*.pro              \
           src/*/*.cpp              \
-          src/*/*.h                \
-          src/*/*.h.win32"
+          src/*/*.h"
 
 RPMFILES="${RPMFILES} ${SPECFILE}"
 
