@@ -1,9 +1,9 @@
 #!/bin/sh
 
-echo "Running qmake..."
-
 test -z "${QMAKE}" && QMAKE="qmake"
 
+echo "Running qmake: ${QMAKE}"
+
 ${QMAKE}
 ${QMAKE}  -o src/Makefile  src/src.pro
 
