@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@vk.crocodile.org>
 
-  $Id: Address.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: Address.cpp,v 1.5 2006/09/10 22:40:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,7 +35,7 @@ using namespace libfwbuilder;
 
 const char *Address::TYPENAME={"Address"};
 
-Address::Address(const FWObject *root) : FWObject(root) {}
+Address::Address(const FWObject *root,bool prepopulate) : FWObject(root,prepopulate) {}
 
 IPAddress Address::getAddress() const { return IPAddress(); }
 Netmask   Address::getNetmask() const { return Netmask(); }
@@ -49,7 +49,8 @@ void Address::setNetmask(const std::string &nm) {}
 FWReference* Address::createRef()
 {
 //    FWObjectReference *ref=new FWObjectReference();
-    FWObjectReference *ref=FWObjectReference::cast(getRoot()->create(FWObjectReference::TYPENAME, true));
+    FWObjectReference *ref =
+        FWObjectReference::cast(getRoot()->create(FWObjectReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
