@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: AddressTable.cpp,v 1.11 2006/09/10 22:40:36 vkurland Exp $
+  $Id: AddressTable.cpp,v 1.12 2006/12/28 07:37:41 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -64,10 +64,11 @@ void AddressTable::loadFromSource() throw(FWException)
     ifstream fs(getSourceName().c_str());
     ostringstream exmess;
     Network *net;
-    FWObject *root=getParent();
+    FWObject *root = getParent();
     string buf;
     size_type pos;
-    int line=1;
+    int line = 1;
+    int cntr = 0;
     if(fs)
     {
        while(!fs.eof())
@@ -88,28 +89,28 @@ void AddressTable::loadFromSource() throw(FWException)
             {
                 try
                 {
-                    net=Network::cast(getRoot()->create(Network::TYPENAME));
-                    *net=buf;
+                    net = Network::cast(getRoot()->create(Network::TYPENAME));
+                    *net = buf;
                     root->add(net);
                     net->setName(buf);
                     if (validateChild(net))
                     {
                         addRef(net);
+                        cntr++;
                     }
                     
                 } catch (FWException &ex) 
                 {
                     
-                    exmess << "Invalid Network: "
+                    exmess << "Invalid address: "
                            << getSourceName() << ":"
                            << line
                            << " \"" << buf << "\"";
                     throw FWException(exmess.str());
-                    delete net;
                 }
             }
             line++;
-       }                   
+       }
     }
     else
     {
