@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: BackgroundOp.h,v 1.2.4.1 2006/03/19 06:07:24 vkurland Exp $
+  $Id: BackgroundOp.h,v 1.4 2006/06/25 04:31:26 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -102,8 +102,12 @@ class BackgroundOp
      * from inside run_impl to check if background operation should be
      * immediately interrupted
      */
-    #define CHECK_STOP { stop_program->lock();\
-      if ( stop_program->peek() ){ stop_program->unlock(); pthread_exit(NULL); }\
+    #define CHECK_STOP_AND_RETURN { stop_program->lock();\
+      if ( stop_program->peek() ){ stop_program->unlock(); return; }\
+      stop_program->unlock(); }
+    
+    #define CHECK_STOP_AND_THROW_EXCEPTION { stop_program->lock();\
+      if ( stop_program->peek() ){ stop_program->unlock(); throw FWException("Interrupted"); }\
       stop_program->unlock(); }
     
     public:
