@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: FWObjectDatabase.cpp,v 1.19 2006/09/15 05:30:33 vkurland Exp $
+  $Id: FWObjectDatabase.cpp,v 1.20 2006/10/15 21:43:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -99,6 +99,7 @@ FWObjectDatabase::FWObjectDatabase():FWObject(), data_file()
 
 //    if(db==NULL) db=this;
 
+    searchId =0;
     lastModified = 0;
 
     setName(TYPENAME);
@@ -116,6 +117,8 @@ FWObjectDatabase::FWObjectDatabase(FWObjectDatabase& d):FWObject()
 
     setName(TYPENAME);
 
+    searchId =0;
+
     init=true;
     *this = d;  // copies entire tree
     setId( getRootId() );
@@ -990,4 +993,105 @@ void FWObjectDatabase::merge( FWObjectDatabase *ndb,
     init=false;
 }
 
+/*
+ * find all objects used by the group 'gr'. REsolves references
+ * recursively (that is, if a group member is another group, this
+ * method descends into it and scans all objects that group uses)
+ */
+void FWObjectDatabase::findObjectsInGroup(Group *g,set<FWObject *> &res)
+{
+    searchId++;
+    _findObjectsInGroup(g,res);
+}
+
+void FWObjectDatabase::_findObjectsInGroup(Group *g,set<FWObject *> &res)
+{
+    if (g->size()==0 || g->getInt(".searchId")==searchId) return;
+    
+    g->setInt(".searchId",searchId);
+    FWObjectReference *ref;
+    Group *sg;
+    FWObject *obj;
+    FWObject::iterator i=g->begin();
+    for(;i!=g->end();++i)
+    {
+        
+       ref=FWObjectReference::cast(*i);
+       if (ref==NULL) 
+       {
+           res.insert(*i);
+           continue;
+       }
+       
+       obj=ref->getPointer();
+       sg=Group::cast(obj);
+       
+       if (sg==NULL)
+       {
+           res.insert(obj);
+           continue;
+       }
+       
+       _findObjectsInGroup(sg,res);
+    }    
+}
+
+bool FWObjectDatabase::_isInIgnoreList(FWObject *o)
+{
+    return (FWOptions::cast(o)!=NULL);
+}
+
+
+/**
+ *  find which firewalls and groups use object 'o' in a subtree rooted
+ *  at object 'p' skip 'deleted objects' library, avoid circular group
+ *  references using temporary flags set in objects this method
+ *  visits.
+ */
+void FWObjectDatabase::findWhereUsed(FWObject *o,FWObject *p,set<FWObject *> &resset)
+{
+    searchId++;
+    _findWhereUsed(o,p,resset);
+}
+
+bool FWObjectDatabase::_findWhereUsed(FWObject *o,FWObject *p,set<FWObject *> &resset)
+{
+    bool res=false;
+        
+    if ( _isInIgnoreList(p) || p->size()==0) return res;
+    
+    if (p->getInt(".searchId")==searchId)
+    {
+        res=p->getBool(".searchResult");
+        return res;
+    }
+
+// set flags to break indefinite recursion in case we encounter circular groups
+    p->setInt(".searchId",searchId);
+    p->setBool(".searchResult",res);   // res==false at this time
+   
+    FWObject::iterator i1=p->begin();
+    for (;i1!=p->end(); ++i1)
+    {
+        if ((*i1)->getId()==FWObjectDatabase::getDeletedObjectsId()) continue;
+
+        FWReference  *ref=FWReference::cast(*i1);
+        if (ref!=NULL)
+        {  // child is a reference
+            FWObject *g=ref->getPointer();
+            if (o==g) res= true;
+            else      res |= _findWhereUsed(o,g,resset);
+        }
+        else    // child is a regular object, not a reference
+        {
+            if (o==(*i1))  res=true;
+            else           res |= _findWhereUsed(o,*i1,resset);
+        }
+    }
+
+    p->setBool(".searchResult",res);
+    if (res) resset.insert(p);
+    return res;
+}
+
 
