@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObjectReference.cpp,v 1.3 2005/10/08 01:39:11 vkurland Exp $
+  $Id: FWObjectReference.cpp,v 1.4 2006/09/10 22:40:36 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,8 @@ FWObjectReference::FWObjectReference():FWReference()
 {
 }
 
-FWObjectReference::FWObjectReference(const FWObject *root) : FWReference(root)
+FWObjectReference::FWObjectReference(const FWObject *root,bool prepopulate) :
+    FWReference(root,prepopulate)
 {}
 
 void FWObjectReference::setPointer(FWObject *p)
