@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObjectReference.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: FWObjectReference.h,v 1.3 2006/09/10 22:40:36 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ class FWObjectReference : public FWReference
     DECLARE_FWOBJECT_SUBTYPE(FWObjectReference);
 
     FWObjectReference();
-    FWObjectReference(const FWObject *root);
+    FWObjectReference(const FWObject *root,bool prepopulate);
 
     void setPointer(FWObject *o);
     void setPointer(ObjectGroup *o);
