@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Firewall.cpp,v 1.10 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Firewall.cpp,v 1.11 2007/07/07 05:36:22 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -218,21 +218,24 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
     string err="Error creating object with type: ";
 
     checkReadOnly();
+    bool xro=obj->getBool("ro"); 
 
     shallowDuplicate(obj,preserve_id);
 
+    setReadOnly(false);
+
     destroyChildren();
 
-    Policy   *op =Policy::cast(obj->getFirstByType(Policy::TYPENAME));
-    FWObject *pol=addCopyOf(op,preserve_id);
+    Policy   *op = Policy::cast(obj->getFirstByType(Policy::TYPENAME));
+    FWObject *pol = addCopyOf(op,preserve_id);
     replaceRef(pol,obj->getId(), getId() );
 
-    NAT      *on =NAT::cast(obj->getFirstByType(NAT::TYPENAME));
-    FWObject *nat=addCopyOf(on,preserve_id);
+    NAT      *on = NAT::cast(obj->getFirstByType(NAT::TYPENAME));
+    FWObject *nat = addCopyOf(on,preserve_id);
     replaceRef(nat,obj->getId(), getId() );
 
-    Routing  *oroute =Routing::cast(obj->getFirstByType(Routing::TYPENAME));
-    FWObject *r=addCopyOf(oroute,preserve_id);
+    Routing  *oroute = Routing::cast(obj->getFirstByType(Routing::TYPENAME));
+    FWObject *r = addCopyOf(oroute,preserve_id);
     replaceRef(r,obj->getId(), getId() );  
     
     FWObjectTypedChildIterator m=obj->findByType(Interface::TYPENAME);
@@ -291,6 +294,7 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
     addCopyOf(o,preserve_id);
 
     setDirty(true);
+    if (xro)  setReadOnly(true);
 
     return *this;
 }
