@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Group.cpp,v 1.3 2006/03/05 05:37:23 vkurland Exp $
+  $Id: Group.cpp,v 1.4 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -42,7 +42,7 @@ const char *Group::TYPENAME={"Group"};
  *  Group should inherit a list of allowed types from its parent upon creation
  */
 Group::Group()  {}
-Group::Group(const FWObject *root) : FWObject(root)
+Group::Group(const FWObject *root,bool prepopulate) : FWObject(root,prepopulate)
 {
     setRoot(root);   // do not remove!
 }
