@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: IPAddress.h,v 1.5 2006/08/18 03:59:32 vkurland Exp $
+  $Id: IPAddress.h,v 1.6 2008/05/05 16:08:29 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -29,6 +29,8 @@
 
 #include <string>
 #include <vector>
+#include <cstdlib>
+#include <cstring>
 
 #ifndef _WIN32
 #  include <sys/types.h>
