@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: IPService.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: IPService.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -41,7 +41,7 @@ class IPService : public Service
     public:
     
     IPService();
-    IPService(const FWObject *root);
+    IPService(const FWObject *root,bool prepopulate);
     virtual ~IPService();
 
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
