@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: InterfacePolicy.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: InterfacePolicy.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,7 @@ InterfacePolicy::InterfacePolicy()
     remStr("comment");
 }
 
-InterfacePolicy::InterfacePolicy(const FWObject *root)
+InterfacePolicy::InterfacePolicy(const FWObject *root,bool prepopulate)
 {
     remStr("name");
     remStr("comment");
@@ -55,7 +55,7 @@ Rule*   InterfacePolicy::createRule()
 {
     FWObjectDatabase* db=getRoot();
     assert(db!=NULL);
-    return Rule::cast( db->create(PolicyRule::TYPENAME, true) );
+    return Rule::cast( db->create(PolicyRule::TYPENAME) );
 }
 
 
