@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Interval.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: Interval.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -53,7 +53,7 @@ Interval::Interval()
 
 }
 
-Interval::Interval(const FWObject *root) : FWObject(root)
+Interval::Interval(const FWObject *root,bool prepopulate) : FWObject(root,prepopulate)
 {
     setInt("from_minute", -1);
     setInt("from_hour", -1);
@@ -207,7 +207,7 @@ void Interval::fromXML(xmlNodePtr root) throw(FWException)
 FWReference* Interval::createRef()
 {
 //    FWIntervalReference *ref=new FWIntervalReference();
-    FWIntervalReference *ref=FWIntervalReference::cast(getRoot()->create(FWIntervalReference::TYPENAME, true));
+    FWIntervalReference *ref=FWIntervalReference::cast(getRoot()->create(FWIntervalReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
