@@ -7,7 +7,7 @@
   Author:  Vadim Kurland     vadim@vk.crocodile.org
            Vadim Zaliva      lord@crocodile.org
 
-  $Id: Logger.cpp,v 1.3 2006/01/21 05:33:41 vkurland Exp $
+  $Id: Logger.cpp,v 1.4 2007/08/02 05:19:28 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -70,6 +70,7 @@ void    Logger::blackhole()
 
 Logger& NullLogger::operator<< (char c)            { return *this;}
 Logger& NullLogger::operator<< (char  *str)        { return *this;}
+Logger& NullLogger::operator<< (const char  *str)  { return *this;}
 Logger& NullLogger::operator<< (const string &str) { return *this;}
 Logger& NullLogger::operator<< (int    i  )        { return *this;}
 Logger& NullLogger::operator<< (long   l  )        { return *this;}
@@ -99,6 +100,16 @@ Logger& QueueLogger::operator<< (char  *str)
     return *this;
 }
 
+Logger& QueueLogger::operator<< (const char  *str)        
+{ 
+    if (blackhole_mode) return *this;
+
+    line_lock.lock();
+    linequeue.push(str);
+    line_lock.unlock();
+    return *this;
+}
+
 Logger& QueueLogger::operator<< (const string &str) 
 { 
     if (blackhole_mode) return *this;
