@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: Management.cpp,v 1.4 2006/09/10 23:44:29 vkurland Exp $
+  $Id: Management.cpp,v 1.5 2007/08/02 05:19:28 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -398,7 +398,6 @@ const char *FWBDManagement::TYPENAME={"FWBDManagement"};
 FWBDManagement::FWBDManagement()
 {
     port = -1 ;
-    key  = NULL ;
     enabled = false ;
 
     // This object does not have standard attributes
@@ -411,7 +410,6 @@ FWBDManagement::FWBDManagement(const FWObject *root,bool prepopulate) :
     FWObject(root,prepopulate)
 {
     port = -1 ;
-    key  = NULL ;
     enabled = false ;
 
     // This object does not have standard attributes
@@ -423,12 +421,11 @@ FWBDManagement::FWBDManagement(const FWObject *root,bool prepopulate) :
 
 FWBDManagement::~FWBDManagement()
 {
-    if (key) delete key;
 }
 
 bool FWBDManagement::isEmpty() const
 {
-    return port==-1 && key==NULL;
+    return port==-1;
 }
 
 bool FWBDManagement::isEnabled() const
@@ -459,18 +456,6 @@ void FWBDManagement::fromXML(xmlNodePtr parent) throw(FWException)
         enabled=(cxx_strcasecmp(n,"True")==0);
         FREEXMLBUFF(n);
     }
-    
-    key = NULL;
-    xmlNodePtr knode = XMLTools::getXmlChildNode(parent, "PublicKey");
-    if(!knode)
-        return; // No PublicKey element
-
-    const char *data = FROMXMLCAST(xmlNodeGetContent(knode));
-    if(!data)
-        return; // Empty public key under FWBDManagement/PublicKey
-    string s=data;
-    FREEXMLBUFF(data);
-    key = new Key(XMLTools::unquote_linefeeds(s), false);
 }
 
 xmlNodePtr FWBDManagement::toXML(xmlNodePtr parent) throw(FWException)
@@ -481,11 +466,6 @@ xmlNodePtr FWBDManagement::toXML(xmlNodePtr parent) throw(FWException)
     
     xmlNodePtr me = FWObject::toXML(parent, false);
  
-    if(key)
-        xmlNewChild(me, NULL, TOXMLCAST("PublicKey"), 
-                    STRTOXMLCAST(XMLTools::unquote_linefeeds(key->getPublicKey()))
-        );
-
     return me;
 }
 
@@ -511,7 +491,6 @@ FWObject& FWBDManagement::shallowDuplicate(const FWObject *o, bool preserve_id)
     cerr << "Port: " << port << endl;
     cerr << "identity_id: " << identity_id << endl;
     cerr << "enabled: " << enabled << endl;
-    cerr << "key: " << key << endl;
     cerr << endl;
 
     cerr << "n:" << endl;
@@ -519,15 +498,12 @@ FWObject& FWBDManagement::shallowDuplicate(const FWObject *o, bool preserve_id)
     cerr << "Port: " << n->port << endl;
     cerr << "identity_id: " << n->identity_id << endl;
     cerr << "enabled: " << n->enabled << endl;
-    cerr << "key: " << n->key << endl;
     cerr << endl;
 #endif
 
     port        = n->getPort();
     identity_id = n->getIdentityId();
     enabled     = n->isEnabled();
-    if (key) delete key;
-    key=n->key;
     FWObject::shallowDuplicate(o, preserve_id);
     return *this;
 }
@@ -552,19 +528,3 @@ void FWBDManagement::setIdentityId(const string &s)
     identity_id = s;
 }
 
-const Key *FWBDManagement::getPublicKey () const
-{
-    return key;
-}
-
-void FWBDManagement::setPublicKey(const Key &k) 
-{
-    if (key) delete key;
-    key = new Key(k);
-}
-
-void FWBDManagement::removePublicKey()
-{
-    if (key) delete key;
-    key = NULL;
-}
