@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: MultiAddress.cpp,v 1.3 2006/05/17 02:27:33 vkurland Exp $
+  $Id: MultiAddress.cpp,v 1.4 2006/09/10 22:40:37 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -50,7 +50,8 @@ MultiAddress::MultiAddress() : FWObject()
     setRunTime(false);
 }
 
-MultiAddress::MultiAddress(const FWObject *root) : FWObject(root) 
+MultiAddress::MultiAddress(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate) 
 {
     source_attribute_name = "";
     setSourceName("");
