@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Network.cpp,v 1.4 2005/11/24 08:42:47 vkurland Exp $
+  $Id: Network.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -46,9 +46,9 @@ Network::Network() : Address() ,
 {
 }
 
-Network::Network(const FWObject *root) : Address(root),
-					 address("0.0.0.0") , 
-					 netmask("0.0.0.0")
+Network::Network(const FWObject *root,bool prepopulate) : Address(root,prepopulate),
+                                                          address("0.0.0.0") , 
+                                                          netmask("0.0.0.0")
 {
 }
 
