@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Policy.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: Policy.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -46,7 +46,7 @@ Policy::Policy() : RuleSet()
     remStr("comment");
 }
 
-Policy::Policy(const FWObject *root) : RuleSet()
+Policy::Policy(const FWObject *root,bool prepopulate) : RuleSet(root,prepopulate)
 {
     remStr("name");
     remStr("comment");
@@ -58,7 +58,7 @@ Rule*   Policy::createRule()
 {
     FWObjectDatabase* db=getRoot();
     assert(db!=NULL);
-    return Rule::cast( db->create(PolicyRule::TYPENAME, true) );
+    return Rule::cast( db->create(PolicyRule::TYPENAME) );
 }
 
 
