@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Rule.cpp,v 1.14 2006/09/10 22:40:37 vkurland Exp $
+  $Id: Rule.cpp,v 1.15 2007/07/19 01:44:21 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -52,7 +52,6 @@ Rule::Rule()
     enable();
     setFallback(false);
     setHidden(false);
-    interface_id="";
 }
 
 Rule::Rule(const FWObject *root,bool prepopulate) : Group(root,prepopulate)
@@ -62,7 +61,6 @@ Rule::Rule(const FWObject *root,bool prepopulate) : Group(root,prepopulate)
     enable();
     setFallback(false);
     setHidden(false);
-    interface_id="";
 }
 
 FWOptions* Rule::getOptionsObject()  {    return NULL;              }
@@ -80,7 +78,6 @@ FWObject& Rule::shallowDuplicate(const FWObject *x, bool preserve_id) throw(FWEx
     fallback=rx->fallback;
     hidden=rx->hidden;
     label=rx->label;
-    interface_id=rx->interface_id;
     unique_id=rx->unique_id;
     abs_rule_number=rx->abs_rule_number;
 
