@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Rule.h,v 1.11 2006/06/03 18:31:36 vkurland Exp $
+  $Id: Rule.h,v 1.13 2007/07/19 01:44:21 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -57,15 +57,13 @@ class Rule : public Group
     std::string label;
     bool        fallback;
     bool        hidden;
-    std::string interface_id;
-    std::string interface_str;
     std::string unique_id;
     int         abs_rule_number;
 
     public:
 
     Rule();
-    Rule(const FWObject *root);
+    Rule(const FWObject *root,bool prepopulate);
 
     DECLARE_FWOBJECT_SUBTYPE(Rule);
 
@@ -82,11 +80,15 @@ class Rule : public Group
     bool isHidden() const { return hidden; }
     void setHidden(bool f) { hidden=f; }
 
-    std::string getInterfaceId() const { return interface_id; }
-    void setInterfaceId(const std::string &iface_id) { interface_id=iface_id; }
+    std::string getInterfaceId() const
+    { return getStr("interface_id"); }
+    void setInterfaceId(const std::string &iface_id)
+    { setStr("interface_id", iface_id); }
 
-    std::string getInterfaceStr() const { return interface_str; }
-    void setInterfaceStr(const std::string &iface_str) { interface_str=iface_str; }
+    std::string getInterfaceStr() const
+    { return getStr("interface_str"); }
+    void setInterfaceStr(const std::string &iface_str)
+    { setStr("interface_str", iface_str); }
 
     std::string getUniqueId() const { return unique_id; }
     void setUniqueId(const std::string &str) { unique_id=str; }
@@ -169,7 +171,7 @@ class PolicyRule : public Rule
 
 
     PolicyRule();
-    PolicyRule(const FWObject *root);
+    PolicyRule(const FWObject *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
     virtual FWObject& shallowDuplicate(const FWObject *obj, bool preserve_id = true) throw(FWException);
@@ -224,7 +226,7 @@ class NATRule : public Rule
     public:
 
     NATRule();
-    NATRule(const FWObject *root);
+    NATRule(const FWObject *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
 
@@ -265,7 +267,7 @@ class RoutingRule : public Rule
     public:
                     
     RoutingRule();
-    RoutingRule(const FWObject *root);
+    RoutingRule(const FWObject *root,bool prepopulate);
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
     virtual xmlNodePtr toXML      (xmlNodePtr parent) throw(FWException);
 
