@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: RuleSet.cpp,v 1.2 2004/09/08 05:34:51 vkurland Exp $
+  $Id: RuleSet.cpp,v 1.3 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -42,7 +42,7 @@ RuleSet::RuleSet()
     setName("RuleSet");
 }
 
-RuleSet::RuleSet(const FWObject *root)
+RuleSet::RuleSet(const FWObject *root,bool prepopulate)
 {
     setName("RuleSet");
 }
