@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva <lord@crocodile.org>
 
-  $Id: Service.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: Service.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,7 +35,7 @@ using namespace std;
 
 const char *Service::TYPENAME={"Service"};
 
-Service::Service(const FWObject *root) : FWObject(root) {}
+Service::Service(const FWObject *root,bool prepopulate) : FWObject(root,prepopulate) {}
 
 string Service::getProtocolName()
 {
@@ -50,7 +50,7 @@ int    Service::getProtocolNumber()
 FWReference* Service::createRef()
 {
 //    FWServiceReference *ref=new FWServiceReference();
-    FWServiceReference *ref=FWServiceReference::cast(getRoot()->create(FWServiceReference::TYPENAME, true));
+    FWServiceReference *ref=FWServiceReference::cast(getRoot()->create(FWServiceReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
