@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ServiceGroup.cpp,v 1.4 2006/03/23 05:50:01 vkurland Exp $
+  $Id: ServiceGroup.cpp,v 1.6 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -41,7 +41,7 @@ using namespace libfwbuilder;
 const char *ServiceGroup::TYPENAME={"ServiceGroup"};
 
 ServiceGroup::ServiceGroup() : Group() {}
-ServiceGroup::ServiceGroup(const FWObject *root) : Group(root) {}
+ServiceGroup::ServiceGroup(const FWObject *root,bool prepopulate) : Group(root,prepopulate) {}
 
 ServiceGroup::~ServiceGroup() {}
 
@@ -58,7 +58,7 @@ bool  ServiceGroup::validateChild(FWObject *o)
 FWReference* ServiceGroup::createRef()
 {
 //    FWServiceReference *ref=new FWServiceReference();
-    FWServiceReference *ref=FWServiceReference::cast(getRoot()->create(FWServiceReference::TYPENAME, true));
+    FWServiceReference *ref=FWServiceReference::cast(getRoot()->create(FWServiceReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
