@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ServiceGroup.h,v 1.2 2004/09/08 05:34:51 vkurland Exp $
+  $Id: ServiceGroup.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -38,7 +38,7 @@ class ServiceGroup : public Group
     public:
 
     ServiceGroup();
-    ServiceGroup(const FWObject *root);
+    ServiceGroup(const FWObject *root,bool prepopulate);
     virtual ~ServiceGroup();
 
     DECLARE_FWOBJECT_SUBTYPE(ServiceGroup);
