@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: UDPService.h,v 1.2 2004/09/08 05:34:52 vkurland Exp $
+  $Id: UDPService.h,v 1.3 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -41,7 +41,7 @@ class UDPService : public Service
     public:
 
     UDPService();
-    UDPService(const FWObject *root);
+    UDPService(const FWObject *root,bool prepopulate);
     virtual ~UDPService();
     
     virtual void fromXML(xmlNodePtr parent) throw(FWException);
