@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@vk.crocodile.org>
 
-  $Id: physAddress.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: physAddress.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,7 +40,8 @@ using namespace std;
 
 const char *physAddress::TYPENAME={"physAddress"};
 
-physAddress::physAddress(const FWObject *root) : Address(root) 
+physAddress::physAddress(const FWObject *root,bool prepopulate) :
+    Address(root,prepopulate) 
 {
     setPhysAddress("00:00:00:00:00:00");
 }
@@ -86,7 +87,7 @@ void physAddress::setPhysAddress(const std::string &s)
 FWReference* physAddress::createRef()
 {
 //    FWObjectReference *ref=new FWObjectReference();
-    FWObjectReference *ref=FWObjectReference::cast(getRoot()->create(FWObjectReference::TYPENAME, true));
+    FWObjectReference *ref=FWObjectReference::cast(getRoot()->create(FWObjectReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
