@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: snmp.cpp,v 1.10 2006/09/20 15:38:00 vkurland Exp $
+  $Id: snmp.cpp,v 1.11 2007/08/02 05:19:28 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -183,7 +183,7 @@ void SNMPQuery::init(string h, string c, int retries_, long timeout_)
     contact   = "" ;
     location  = "" ;
 
-    char *snmp_out_opt = "n";
+    char *snmp_out_opt = (char*)("n");
     snmp_out_toggle_options(snmp_out_opt);
 }
 
@@ -980,7 +980,7 @@ multimap<string, SNMPVariable* > SNMPConnection::walk(const string &variable) th
                 str << "SNMPSession: SNMP error, status ";
                 str << status;
                 int liberr,syserr;
-                char *errstr = "";
+                char *errstr = (char*)("");
                 snmp_error(session, &liberr, &syserr, &errstr);
                 str << " " << errstr;
                 throw FWException(str.str());
