@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Compiler.cpp,v 1.28 2006/12/28 07:37:41 vkurland Exp $
+  $Id: Compiler.cpp,v 1.29 2008/03/10 03:41:57 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1022,8 +1022,20 @@ int  Compiler::emptyGroupsInRE::countChildren(FWObject *obj)
     {
 	FWObject *o= *i;
 	if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-        if (Group::cast(o)!=NULL) n+=countChildren(o); // group itself does not count since it can be empty, too
-        else n++;   // but if it is not a group, then we count it.
+        
+        // Check if this is a group, if yes, then count its children
+        // recursively. Group itself does not count since it can be
+        // empty, too.  However if this is MultiAddress object with
+        // run-time processing, it does not count as an empty group
+        // since we have no way to know at compile time if it will
+        // have some addresses at run time. So we just count it as a
+        // regular object.
+
+        if (MultiAddress::cast(o)!=NULL && MultiAddress::cast(o)->isRunTime())
+            n++;
+        else
+            if (Group::cast(o)!=NULL)  n += countChildren(o);
+            else n++;   // but if it is not a group, then we count it.
     }
     return n;
 }
