@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Compiler_ops.cpp,v 1.6 2005/01/25 07:33:04 vkurland Exp $
+  $Id: Compiler_ops.cpp,v 1.7 2006/03/06 03:00:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -264,13 +264,13 @@ bool fwcompiler::checkForShadowing(const Address &o1,const Address &o2)
     if (Interface::isA(&o1))
     {
         const Interface *intf=Interface::constcast(&o1);
-        if (intf->isDyn() || intf->isUnnumbered()) return false;
+        if (!intf->isRegular()) return false;
     }
 
     if (Interface::isA(&o2))
     {
         const Interface *intf=Interface::constcast(&o2);
-        if (intf->isDyn() || intf->isUnnumbered()) return false;
+        if (!intf->isRegular()) return false;
     }
 
     if (physAddress::isA(&o1) && physAddress::isA(&o2))
@@ -407,7 +407,7 @@ bool fwcompiler::operator==(const Address &o1,const Address &o2)
     {
         const Interface *i1=Interface::constcast(&o1);
         const Interface *i2=Interface::constcast(&o2);
-        if ( (i1->isDyn() || i1->isUnnumbered()) && (i2->isDyn() || i2->isUnnumbered()) )
+        if ( !i1->isRegular() && !i2->isRegular() )
         {
             return i1->getName()==i2->getName();
         }
