@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler.cpp,v 1.5 2006/05/16 22:39:36 vkurland Exp $
+  $Id: NATCompiler.cpp,v 1.6 2006/09/09 05:02:58 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -329,7 +329,7 @@ bool NATCompiler::ConvertToAtomicForOriginal::processNext()
 	    for (FWObject::iterator i3=osrv->begin(); i3!=osrv->end(); ++i3) 
             {
                 NATRule *r = NATRule::cast(
-                    compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                    compiler->dbcopy->create(NATRule::TYPENAME) );
                 r->duplicate(rule);
                 compiler->temp_ruleset->add(r);
                 
@@ -378,7 +378,7 @@ bool NATCompiler::ConvertToAtomicForAddresses::processNext()
 		for (FWObject::iterator i5=tdst->begin(); i5!=tdst->end(); ++i5) 
                 {
 		    NATRule *r = NATRule::cast(
-			compiler->dbcopy->create(NATRule::TYPENAME,false) );
+			compiler->dbcopy->create(NATRule::TYPENAME) );
 		    r->duplicate(rule);
                     compiler->temp_ruleset->add(r);
 
@@ -425,7 +425,7 @@ bool NATCompiler::ConvertToAtomicForTSrc::processNext()
     for (FWObject::iterator i1=tsrc->begin(); i1!=tsrc->end(); ++i1) 
     {
         NATRule *r = NATRule::cast(
-            compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
 
@@ -451,7 +451,7 @@ bool NATCompiler::ConvertToAtomicForTDst::processNext()
     for (FWObject::iterator i1=tsrc->begin(); i1!=tsrc->end(); ++i1) 
     {
         NATRule *r = NATRule::cast(
-            compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
 
@@ -477,7 +477,7 @@ bool NATCompiler::ConvertToAtomicForTSrv::processNext()
     for (FWObject::iterator i1=tsrc->begin(); i1!=tsrc->end(); ++i1) 
     {
         NATRule *r = NATRule::cast(
-            compiler->dbcopy->create(NATRule::TYPENAME,false) );
+            compiler->dbcopy->create(NATRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
 
@@ -521,7 +521,7 @@ bool NATCompiler::ConvertToAtomic::processNext()
 			for (FWObject::iterator i6=tsrv->begin(); i6!=tsrv->end(); ++i6) 
                         {
 			    NATRule *r = NATRule::cast(
-				compiler->dbcopy->create(NATRule::TYPENAME,false) );
+				compiler->dbcopy->create(NATRule::TYPENAME) );
 			    r->duplicate(rule);
                             compiler->temp_ruleset->add(r);
 
@@ -648,7 +648,7 @@ bool NATCompiler::splitODstForSNAT::processNext()
                 for (j=il.begin(); j!=il.end(); j++)
                 {
                     NATRule *r= NATRule::cast(
-                        compiler->dbcopy->create(NATRule::TYPENAME,false) );
+                        compiler->dbcopy->create(NATRule::TYPENAME) );
                     compiler->temp_ruleset->add(r);
                     r->duplicate(rule);
                     RuleElementODst *nodst=r->getODst();
