@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler.cpp,v 1.21 2007/05/22 21:33:56 vkurland Exp $
+  $Id: PolicyCompiler.cpp,v 1.22 2008/05/08 17:41:21 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -181,6 +181,16 @@ bool PolicyCompiler::checkForShadowing(const PolicyRule &r1,const PolicyRule &r2
     if (r1.getAction()==PolicyRule::Route  ||
         r2.getAction()==PolicyRule::Route ) return false;
 
+    /*
+     * the problem with branching rules is that it is combination of
+     * the head rule and rules in the branch rather than a single rule
+     * that can shadow other rules below them. Our current mechanism for
+     * shadowing detection does not support this so all we can do is
+     * skip rules with action Branch.
+     */
+    if (r1.getAction()==PolicyRule::Branch  ||
+        r2.getAction()==PolicyRule::Branch ) return false;
+
 
     Address  *src1=getFirstSrc(&r1);
     Address  *dst1=getFirstDst(&r1);
