@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler.h,v 1.8 2007/01/05 07:31:56 vkurland Exp $
+  $Id: PolicyCompiler.h,v 1.9 2007/05/08 02:13:37 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -219,6 +219,13 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(ConvertToAtomic);
 
+	/**
+	 * simply check if TCPService object with "established" flag
+         * set is used in Service and abort with an error saying that
+         * target firewall does not support this. Use for pretty much
+         * every platform except ipfw and router ACLs
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(CheckForTCPEstablished);
 
         /**
          *  deals with recursive groups in Src. See description for
