@@ -187,7 +187,7 @@ bool RoutingCompiler::ConvertToAtomicForDST::processNext()
     for (FWObject::iterator it=dst->begin(); it!=dst->end(); ++it) {
 
         RoutingRule *r = RoutingRule::cast(
-            compiler->dbcopy->create(RoutingRule::TYPENAME,false) );
+            compiler->dbcopy->create(RoutingRule::TYPENAME) );
         r->duplicate(rule);
         compiler->temp_ruleset->add(r);
 
